@@ -40,7 +40,7 @@ var languageNames = {
 "lt": "Lituano",
 "lv": "Letão",
 "mk": "Macedônio",
-"nb": "Noreguês Bokmål",
+"nb": "Norueguês Bokmål",
 "ne": "Nepalês",
 "nl": "Holandês",
 "nn": "Norueguês Nynorsk",
